"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports["default"] = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var _expressLocale = _interopRequireDefault(require("express-locale"));

var _graphql = require("graphql");

var _graphqlTypeJson = _interopRequireDefault(require("graphql-type-json"));

var hooks = _interopRequireWildcard(require("./hooks"));

// @TODO: let a configuration to tell where to fetch the locale files
var loadLocaleFile = function loadLocaleFile(locale) {
  return new Promise(function (resolve, reject) {
    var origin = process.env.NODE_ENV === 'production' ? 'node_build/src' : 'src';

    var filePath = _path["default"].join(process.cwd(), origin, 'locale', locale.toLowerCase() + ".json");

    _fs["default"].readFile(filePath, 'utf8', function (err, data) {
      return err ? reject(err) : resolve(data);
    });
  });
};

var loadMessages = function loadMessages(locale) {
  var data;
  return _regenerator["default"].async(function loadMessages$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          data = null; // try specific language "en_GB"

          _context.prev = 1;
          _context.next = 4;
          return _regenerator["default"].awrap(loadLocaleFile(locale));

        case 4:
          data = _context.sent;
          _context.next = 9;
          break;

        case 7:
          _context.prev = 7;
          _context.t0 = _context["catch"](1);

        case 9:
          _context.prev = 9;
          _context.next = 12;
          return _regenerator["default"].awrap(loadLocaleFile(locale.split('_').shift()));

        case 12:
          data = _context.sent;
          _context.next = 18;
          break;

        case 15:
          _context.prev = 15;
          _context.t1 = _context["catch"](9);
          throw new Error("localization \"" + locale + "\" not available");

        case 18:
          _context.prev = 18;
          return _context.abrupt("return", JSON.parse(data));

        case 22:
          _context.prev = 22;
          _context.t2 = _context["catch"](18);
          throw new Error("localization \"" + locale + "\" is corrupted");

        case 25:
        case "end":
          return _context.stop();
      }
    }
  }, null, null, [[1, 7], [9, 15], [18, 22]]);
};

var localeQuery = {
  description: 'Provides localized messages',
  args: {
    locale: {
      type: new _graphql.GraphQLNonNull(_graphql.GraphQLString)
    }
  },
  type: new _graphql.GraphQLNonNull(new _graphql.GraphQLObjectType({
    name: 'Locale',
    fields: {
      locale: {
        type: new _graphql.GraphQLNonNull(_graphql.GraphQLString)
      },
      messages: {
        type: _graphqlTypeJson["default"]
      }
    }
  })),
  resolve: function resolve(params, args) {
    return _regenerator["default"].async(function resolve$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.t0 = args.locale;
            _context2.next = 3;
            return _regenerator["default"].awrap(loadMessages(args.locale));

          case 3:
            _context2.t1 = _context2.sent;
            return _context2.abrupt("return", {
              locale: _context2.t0,
              messages: _context2.t1
            });

          case 5:
          case "end":
            return _context2.stop();
        }
      }
    });
  }
};

var _default = function _default(_ref) {
  var registerHook = _ref.registerHook,
      registerAction = _ref.registerAction;
  registerHook(hooks);
  registerAction({
    hook: '$EXPRESS_GRAPHQL',
    name: hooks.FEATURE_NAME,
    handler: function handler(_ref2) {
      var registerQuery = _ref2.registerQuery;
      registerQuery('locale', localeQuery);
    }
  });
  registerAction({
    hook: '$EXPRESS_MIDDLEWARE',
    name: hooks.FEATURE_NAME,
    handler: function handler(_ref3, _ref4) {
      var registerMiddleware = _ref3.registerMiddleware;
      var getConfig = _ref4.getConfig;
      var locale = getConfig('locale', {});
      var config = {
        "default": locale["default"] || 'en_US',
        priority: locale.priority || ['query', 'cookie', 'accept-language', 'default']
      }; // Default value is "react-ssr--locale"

      config.cookie = {
        name: locale && locale.cookieName ? locale.cookieName : (process.env.REACT_APP_ID || 'forrestjs') + "--locale"
      };

      if (locale.queryName) {
        config.query = {
          name: locale.queryName
        };
      }

      if (locale.hostname) {
        config.hostname = locale.hostname;
      }

      if (locale.map) {
        config.map = locale.map;
      }

      if (locale.allowed) {
        config.allowed = locale.allowed;
      }

      registerMiddleware((0, _expressLocale["default"])(config));
    }
  });
};

exports["default"] = _default;